@@ -40,7 +40,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "EnchantBrokerTestFixture_8h_source.html",
-"structEnchantPwl__TestFixture.html"
+"structEnchantGetPrefixDirTestFixture.html#add23ebb2ccd267992f6922d6971eba5d"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
